/*
 * BLE Shield RFID Reader Sketch for Arduino 1.0
 * by Dr. Michael Kroll 2012
 * v1.0.0 2012-07-11
 */
#include <Wire.h>
#include <Adafruit_NFCShield_I2C.h>

#define IRQ   (2)
#define RESET (3)  // Not connected by default on the NFC Shield

Adafruit_NFCShield_I2C nfc(IRQ, RESET);

void setup(void) {
  Serial.begin(19200);

  nfc.begin();

  uint32_t versiondata = nfc.getFirmwareVersion();
  if (!versiondata) {
    while (1); // halt
  }
  
  // configure board to read RFID tags
  nfc.SAMConfig();    
}

void loop(void) {
  boolean success;
  uint8_t uid[] = { 0, 0, 0, 0, 0, 0, 0 };                               // Buffer to store the returned UID
  uint8_t pad[] = { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 }; // Buffer for writing the padding
  uint8_t uidLength;                                                     // Length of the UID (4 or 7 bytes depending on ISO14443A card type)
  
  uint8_t bleBufferLength = 16;
  uint8_t paddingSize = 0;
  
  // Wait for an ISO14443A type cards (Mifare, etc.).  When one is found
  // 'uid' will be populated with the UID, and uidLength will indicate
  // if the uid is 4 bytes (Mifare Classic) or 7 bytes (Mifare Ultralight)
  success = nfc.readPassiveTargetID(PN532_MIFARE_ISO14443A, &uid[0], &uidLength);
  
  if (success) {
    paddingSize = bleBufferLength - uidLength*2;
    // add padding depending of the size of the TAG UID   
    for (uint8_t i=0; i < paddingSize; i++)  {
      Serial.print(pad[i], HEX); 
    }
    
    // write the UID of the tag.
    for (uint8_t i=0; i < uidLength; i++)  {
      Serial.print(uid[i], HEX); 
    }
    
    // Wait 1 second before continuing
    delay(1000);
  }
}
